@@ -21,9 +21,9 @@ class QComboBox;
 class QCheckBox;
 class QLabel;
 class KConfigDialogManager;
-class QPushButton;
 class QStackedLayout;
 
+class CaptureAreaComboBox;
 class KSImageWidget;
 class ProgressButton;
 class SmartSpinBox;
@@ -44,7 +44,7 @@ public:
     enum class State { TakeNewScreenshot, Cancel };
 
     int imagePaddingWidth() const;
-    bool isScreenshotSet();
+    bool isScreenshotSet() const;
 
 Q_SIGNALS:
 
@@ -64,6 +64,7 @@ public Q_SLOTS:
 #ifdef KIMAGEANNOTATOR_FOUND
     void showAnnotator();
     void hideAnnotator();
+    QSize sizeHintWhenAnnotating();
 #endif
 
 private Q_SLOTS:
@@ -78,9 +79,9 @@ private:
     QVBoxLayout *mRightLayout{nullptr};
     QFormLayout *mCaptureModeForm{nullptr};
     QVBoxLayout *mContentOptionsForm{nullptr};
-    KSImageWidget *mImageWidget{nullptr};
+    KSImageWidget *const mImageWidget;
     ProgressButton *mTakeScreenshotButton;
-    QComboBox *mCaptureArea{nullptr};
+    CaptureAreaComboBox *mCaptureArea{nullptr};
     SmartSpinBox *mDelayMsec{nullptr};
     QCheckBox *mCaptureOnClick{nullptr};
     QCheckBox *mMousePointer{nullptr};
